==> therion_5.3.10.orig.tar.gz: therion/thsymbolsets.cxx <==
#include "thsymbolsets.h"

int thsymsets_symbols [thsymbolset_size][thsymsets_size];

int thsymsets_figure [thsymbolset_size][thsymsets_size+1];

int thsymsets_order[thsymbolset_size];

int thsymsets_count[thsymsets_size];

std::map<unsigned, std::string> thsymsets_comment;




void thsymsets_symbols_init() {
	size_t i, j;
	for(i = 0; i <= thsymbolset_size; i++)
		for(j = 0; j < thsymsets_size; j++) 
			thsymsets_symbols[i][j] = 0;
		
	
	thsymsets_symbols[SYMP_AIRDRAUGHT][1] = 1;
	thsymsets_symbols[SYMP_AIRDRAUGHT][7] = 1;
	thsymsets_symbols[SYMP_AIRDRAUGHT_SUMMER][7] = 1;
	thsymsets_symbols[SYMP_AIRDRAUGHT_WINTER][7] = 1;
	thsymsets_symbols[SYMP_ANASTOMOSIS][7] = 1;
	thsymsets_symbols[SYMP_ANCHOR][5] = 1;
	thsymsets_symbols[SYMP_ARAGONITE][3] = 1;
	thsymsets_symbols[SYMP_ARCHEOMATERIAL][7] = 1;
	thsymsets_symbols[SYMP_BEDROCK][0] = 1;
	thsymsets_symbols[SYMP_BLOCKS][1] = 1;
	thsymsets_symbols[SYMP_BLOCKS][7] = 1;
	thsymsets_symbols[SYMP_BREAKDOWNCHOKE][1] = 1;
	thsymsets_symbols[SYMP_BREAKDOWNCHOKE][3] = 1;
	thsymsets_symbols[SYMP_BRIDGE][5] = 1;
	thsymsets_symbols[SYMP_CAMP][5] = 1;
	thsymsets_symbols[SYMP_CAVEPEARL][5] = 1;
	thsymsets_symbols[SYMP_CLAY][1] = 1;
	thsymsets_symbols[SYMP_CLAY][5] = 1;
	thsymsets_symbols[SYMP_CLAYCHOKE][1] = 1;
	thsymsets_symbols[SYMP_CLAYTREE][1] = 1;
	thsymsets_symbols[SYMP_CONTINUATION][7] = 1;
	thsymsets_symbols[SYMP_CRYSTAL][1] = 1;
	thsymsets_symbols[SYMP_CRYSTAL][7] = 1;
	thsymsets_symbols[SYMP_CURTAIN][7] = 1;
	thsymsets_symbols[SYMP_DEBRIS][1] = 1;
	thsymsets_symbols[SYMP_DEBRIS][7] = 1;
	thsymsets_symbols[SYMP_DIG][7] = 1;
	thsymsets_symbols[SYMP_DISK][7] = 1;
	thsymsets_symbols[SYMP_ENTRANCE][1] = 1;
	thsymsets_symbols[SYMP_ENTRANCE][7] = 1;
	thsymsets_symbols[SYMP_FIXEDLADDER][5] = 1;
	thsymsets_symbols[SYMP_FLOWSTONE][7] = 1;
	thsymsets_symbols[SYMP_FLOWSTONECHOKE][3] = 1;
	thsymsets_symbols[SYMP_FLUTE][7] = 1;
	thsymsets_symbols[SYMP_GRADIENT][1] = 1;
	thsymsets_symbols[SYMP_GRADIENT][2] = 1;
	thsymsets_symbols[SYMP_GRADIENT][3] = 1;
	thsymsets_symbols[SYMP_GRADIENT][7] = 1;
	thsymsets_symbols[SYMP_GUANO][7] = 1;
	thsymsets_symbols[SYMP_GYPSUM][3] = 1;
	thsymsets_symbols[SYMP_GYPSUMFLOWER][3] = 1;
	thsymsets_symbols[SYMP_HELICTITE][7] = 1;
	thsymsets_symbols[SYMP_ICE][1] = 1;
	thsymsets_symbols[SYMP_ICE][7] = 1;
	thsymsets_symbols[SYMP_ICEPILLAR][1] = 1;
	thsymsets_symbols[SYMP_ICESTALACTITE][1] = 1;
	thsymsets_symbols[SYMP_ICESTALAGMITE][1] = 1;
	thsymsets_symbols[SYMP_KARREN][7] = 1;
	thsymsets_symbols[SYMP_LOWEND][3] = 1;
	thsymsets_symbols[SYMP_LOWEND][7] = 1;
	thsymsets_symbols[SYMP_MOONMILK][7] = 1;
	thsymsets_symbols[SYMP_NARROWEND][7] = 1;
	thsymsets_symbols[SYMP_NOEQUIPMENT][5] = 1;
	thsymsets_symbols[SYMP_PALEOMATERIAL][7] = 1;
	thsymsets_symbols[SYMP_PEBBLES][1] = 1;
	thsymsets_symbols[SYMP_PEBBLES][7] = 1;
	thsymsets_symbols[SYMP_PILLAR][1] = 1;
	thsymsets_symbols[SYMP_PILLAR][7] = 1;
	thsymsets_symbols[SYMP_POPCORN][7] = 1;
	thsymsets_symbols[SYMP_RAFT][3] = 1;
	thsymsets_symbols[SYMP_RAFTCONE][3] = 1;
	thsymsets_symbols[SYMP_RIMSTONEDAM][0] = 1;
	thsymsets_symbols[SYMP_RIMSTONEPOOL][0] = 1;
	thsymsets_symbols[SYMP_ROOT][0] = 1;
	thsymsets_symbols[SYMP_ROPE][5] = 1;
	thsymsets_symbols[SYMP_ROPELADDER][5] = 1;
	thsymsets_symbols[SYMP_SAND][1] = 1;
	thsymsets_symbols[SYMP_SAND][7] = 1;
	thsymsets_symbols[SYMP_SCALLOP][7] = 1;
	thsymsets_symbols[SYMP_SINK][1] = 1;
	thsymsets_symbols[SYMP_SINK][5] = 1;
	thsymsets_symbols[SYMP_SNOW][5] = 1;
	thsymsets_symbols[SYMP_SODASTRAW][7] = 1;
	thsymsets_symbols[SYMP_SPRING][1] = 1;
	thsymsets_symbols[SYMP_SPRING][5] = 1;
	thsymsets_symbols[SYMP_STALACTITE][1] = 1;
	thsymsets_symbols[SYMP_STALACTITE][7] = 1;
	thsymsets_symbols[SYMP_STALAGMITE][1] = 1;
	thsymsets_symbols[SYMP_STALAGMITE][7] = 1;
	thsymsets_symbols[SYMP_STATION][5] = 1;
	thsymsets_symbols[SYMP_STATION_FIXED][0] = 1;
	thsymsets_symbols[SYMP_STATION_FIXED][1] = 1;
	thsymsets_symbols[SYMP_STATION_NATURAL][0] = 1;
	thsymsets_symbols[SYMP_STATION_PAINTED][1] = 1;
	thsymsets_symbols[SYMP_STATION_PAINTED][5] = 1;
	thsymsets_symbols[SYMP_STATION_TEMPORARY][0] = 1;
	thsymsets_symbols[SYMP_STATION_TEMPORARY][1] = 1;
	thsymsets_symbols[SYMP_STATION_TEMPORARY][5] = 1;
	thsymsets_symbols[SYMP_STEPS][5] = 1;
	thsymsets_symbols[SYMP_TRAVERSE][5] = 1;
	thsymsets_symbols[SYMP_VEGETABLEDEBRIS][0] = 1;
	thsymsets_symbols[SYMP_WALLCALCITE][7] = 1;
	thsymsets_symbols[SYMP_WATER][1] = 1;
	thsymsets_symbols[SYMP_WATER][7] = 1;
	thsymsets_symbols[SYMP_WATERFLOW_INTERMITTENT][7] = 1;
	thsymsets_symbols[SYMP_WATERFLOW_PALEO][7] = 1;
	thsymsets_symbols[SYMP_WATERFLOW_PERMANENT][7] = 1;
	thsymsets_symbols[SYML_ARROW][5] = 1;
	thsymsets_symbols[SYML_BORDER_PRESUMED][5] = 1;
	thsymsets_symbols[SYML_BORDER_TEMPORARY][5] = 1;
	thsymsets_symbols[SYML_BORDER_VISIBLE][5] = 1;
	thsymsets_symbols[SYML_CEILINGMEANDER][4] = 1;
	thsymsets_symbols[SYML_CEILINGMEANDER][5] = 1;
	thsymsets_symbols[SYML_CEILINGMEANDER][7] = 1;
	thsymsets_symbols[SYML_CEILINGSTEP][4] = 1;
	thsymsets_symbols[SYML_CEILINGSTEP][5] = 1;
	thsymsets_symbols[SYML_CEILINGSTEP][7] = 1;
	thsymsets_symbols[SYML_CHIMNEY][4] = 1;
	thsymsets_symbols[SYML_CHIMNEY][7] = 1;
	thsymsets_symbols[SYML_CONTOUR][1] = 1;
	thsymsets_symbols[SYML_CONTOUR][5] = 1;
	thsymsets_symbols[SYML_CONTOUR][7] = 1;
	thsymsets_symbols[SYML_FLOORMEANDER][5] = 1;
	thsymsets_symbols[SYML_FLOORSTEP][1] = 1;
	thsymsets_symbols[SYML_FLOORSTEP][7] = 1;
	thsymsets_symbols[SYML_FLOWSTONE][1] = 1;
	thsymsets_symbols[SYML_FLOWSTONE][7] = 1;
	thsymsets_symbols[SYML_GRADIENT][2] = 1;
	thsymsets_symbols[SYML_GRADIENT][7] = 1;
	thsymsets_symbols[SYML_MAPCONNECTION][5] = 1;
	thsymsets_symbols[SYML_MOONMILK][7] = 1;
	thsymsets_symbols[SYML_OVERHANG][1] = 1;
	thsymsets_symbols[SYML_OVERHANG][5] = 1;
	thsymsets_symbols[SYML_PIT][1] = 1;
	thsymsets_symbols[SYML_PIT][7] = 1;
	thsymsets_symbols[SYML_ROCKBORDER][7] = 1;
	thsymsets_symbols[SYML_ROCKEDGE][7] = 1;
	thsymsets_symbols[SYML_ROPE][5] = 1;
	thsymsets_symbols[SYML_SECTION][5] = 1;
	thsymsets_symbols[SYML_SLOPE][2] = 1;
	thsymsets_symbols[SYML_SLOPE][5] = 1;
	thsymsets_symbols[SYML_SURVEY_CAVE][1] = 1;
	thsymsets_symbols[SYML_SURVEY_CAVE][5] = 1;
	thsymsets_symbols[SYML_SURVEY_CAVE][7] = 1;
	thsymsets_symbols[SYML_SURVEY_SURFACE][5] = 1;
	thsymsets_symbols[SYML_WALL_BEDROCK][7] = 1;
	thsymsets_symbols[SYML_WALL_BLOCKS][1] = 1;
	thsymsets_symbols[SYML_WALL_BLOCKS][5] = 1;
	thsymsets_symbols[SYML_WALL_CLAY][1] = 1;
	thsymsets_symbols[SYML_WALL_CLAY][5] = 1;
	thsymsets_symbols[SYML_WALL_DEBRIS][1] = 1;
	thsymsets_symbols[SYML_WALL_DEBRIS][5] = 1;
	thsymsets_symbols[SYML_WALL_FLOWSTONE][1] = 1;
	thsymsets_symbols[SYML_WALL_ICE][1] = 1;
	thsymsets_symbols[SYML_WALL_ICE][5] = 1;
	thsymsets_symbols[SYML_WALL_MOONMILK][1] = 1;
	thsymsets_symbols[SYML_WALL_OVERLYING][1] = 1;
	thsymsets_symbols[SYML_WALL_PEBBLES][1] = 1;
	thsymsets_symbols[SYML_WALL_PEBBLES][5] = 1;
	thsymsets_symbols[SYML_WALL_PIT][1] = 1;
	thsymsets_symbols[SYML_WALL_PRESUMED][4] = 1;
	thsymsets_symbols[SYML_WALL_PRESUMED][7] = 1;
	thsymsets_symbols[SYML_WALL_SAND][1] = 1;
	thsymsets_symbols[SYML_WALL_SAND][5] = 1;
	thsymsets_symbols[SYML_WALL_UNDERLYING][1] = 1;
	thsymsets_symbols[SYML_WALL_UNDERLYING][7] = 1;
	thsymsets_symbols[SYML_WALL_UNSURVEYED][5] = 1;
	thsymsets_symbols[SYML_WATERFLOW_CONJECTURAL][5] = 1;
	thsymsets_symbols[SYML_WATERFLOW_INTERMITTENT][5] = 1;
	thsymsets_symbols[SYML_WATERFLOW_PERMANENT][7] = 1;
	thsymsets_symbols[SYMA_BEDROCK][5] = 1;
	thsymsets_symbols[SYMA_BLOCKS][1] = 1;
	thsymsets_symbols[SYMA_BLOCKS][5] = 1;
	thsymsets_symbols[SYMA_CLAY][1] = 1;
	thsymsets_symbols[SYMA_CLAY][5] = 1;
	thsymsets_symbols[SYMA_DEBRIS][1] = 1;
	thsymsets_symbols[SYMA_DEBRIS][5] = 1;
	thsymsets_symbols[SYMA_DEBRIS][7] = 1;
	thsymsets_symbols[SYMA_DIMENSIONS][5] = 1;
	thsymsets_symbols[SYMA_FLOWSTONE][0] = 1;
	thsymsets_symbols[SYMA_ICE][1] = 1;
	thsymsets_symbols[SYMA_ICE][5] = 1;
	thsymsets_symbols[SYMA_MOONMILK][5] = 1;
	thsymsets_symbols[SYMA_PEBBLES][1] = 1;
	thsymsets_symbols[SYMA_PEBBLES][5] = 1;
	thsymsets_symbols[SYMA_SAND][1] = 1;
	thsymsets_symbols[SYMA_SAND][7] = 1;
	thsymsets_symbols[SYMA_SNOW][1] = 1;
	thsymsets_symbols[SYMA_SNOW][5] = 1;
	thsymsets_symbols[SYMA_SUMP][1] = 1;
	thsymsets_symbols[SYMA_SUMP][5] = 1;
	thsymsets_symbols[SYMA_SUMP][7] = 1;
	thsymsets_symbols[SYMA_WATER][1] = 1;
	thsymsets_symbols[SYMA_WATER][5] = 1;
	thsymsets_symbols[SYMA_WATER][7] = 1;
}

==> therion_5.3.13.orig.tar.gz: therion/thsymbolsets.cxx <==
#include "thsymbolsets.h"

int thsymsets_symbols [thsymbolset_size][thsymsets_size];

int thsymsets_figure [thsymbolset_size][thsymsets_size+1];

int thsymsets_order[thsymbolset_size];

int thsymsets_count[thsymsets_size];

std::map<unsigned, std::string> thsymsets_comment;




void thsymsets_symbols_init() {
	size_t i, j;
	for(i = 0; i <= thsymbolset_size; i++)
		for(j = 0; j < thsymsets_size; j++) 
			thsymsets_symbols[i][j] = 0;
		
	
	thsymsets_symbols[SYMP_AIRDRAUGHT][1] = 1;
	thsymsets_symbols[SYMP_AIRDRAUGHT][7] = 1;
	thsymsets_symbols[SYMP_AIRDRAUGHT_SUMMER][7] = 1;
	thsymsets_symbols[SYMP_AIRDRAUGHT_WINTER][7] = 1;
	thsymsets_symbols[SYMP_ANASTOMOSIS][7] = 1;
	thsymsets_symbols[SYMP_ANCHOR][5] = 1;
	thsymsets_symbols[SYMP_ARAGONITE][3] = 1;
	thsymsets_symbols[SYMP_ARCHEOMATERIAL][7] = 1;
	thsymsets_symbols[SYMP_BEDROCK][0] = 1;
	thsymsets_symbols[SYMP_BLOCKS][1] = 1;
	thsymsets_symbols[SYMP_BLOCKS][7] = 1;
	thsymsets_symbols[SYMP_BREAKDOWNCHOKE][1] = 1;
	thsymsets_symbols[SYMP_BREAKDOWNCHOKE][3] = 1;
	thsymsets_symbols[SYMP_BRIDGE][5] = 1;
	thsymsets_symbols[SYMP_CAMP][5] = 1;
	thsymsets_symbols[SYMP_CAVEPEARL][5] = 1;
	thsymsets_symbols[SYMP_CLAY][1] = 1;
	thsymsets_symbols[SYMP_CLAY][5] = 1;
	thsymsets_symbols[SYMP_CLAYCHOKE][1] = 1;
	thsymsets_symbols[SYMP_CLAYTREE][1] = 1;
	thsymsets_symbols[SYMP_CONTINUATION][7] = 1;
	thsymsets_symbols[SYMP_CRYSTAL][1] = 1;
	thsymsets_symbols[SYMP_CRYSTAL][7] = 1;
	thsymsets_symbols[SYMP_CURTAIN][7] = 1;
	thsymsets_symbols[SYMP_DEBRIS][1] = 1;
	thsymsets_symbols[SYMP_DEBRIS][7] = 1;
	thsymsets_symbols[SYMP_DIG][7] = 1;
	thsymsets_symbols[SYMP_DISK][7] = 1;
	thsymsets_symbols[SYMP_ENTRANCE][1] = 1;
	thsymsets_symbols[SYMP_ENTRANCE][7] = 1;
	thsymsets_symbols[SYMP_FIXEDLADDER][5] = 1;
	thsymsets_symbols[SYMP_FLOWSTONE][7] = 1;
	thsymsets_symbols[SYMP_FLOWSTONECHOKE][3] = 1;
	thsymsets_symbols[SYMP_FLUTE][7] = 1;
	thsymsets_symbols[SYMP_GRADIENT][1] = 1;
	thsymsets_symbols[SYMP_GRADIENT][2] = 1;
	thsymsets_symbols[SYMP_GRADIENT][3] = 1;
	thsymsets_symbols[SYMP_GRADIENT][5] = 1;
	thsymsets_symbols[SYMP_GRADIENT][7] = 1;
	thsymsets_symbols[SYMP_GUANO][7] = 1;
	thsymsets_symbols[SYMP_GYPSUM][3] = 1;
	thsymsets_symbols[SYMP_GYPSUMFLOWER][3] = 1;
	thsymsets_symbols[SYMP_HANDRAIL][5] = 1;
	thsymsets_symbols[SYMP_HELICTITE][7] = 1;
	thsymsets_symbols[SYMP_ICE][1] = 1;
	thsymsets_symbols[SYMP_ICE][7] = 1;
	thsymsets_symbols[SYMP_ICEPILLAR][1] = 1;
	thsymsets_symbols[SYMP_ICESTALACTITE][1] = 1;
	thsymsets_symbols[SYMP_ICESTALAGMITE][1] = 1;
	thsymsets_symbols[SYMP_KARREN][7] = 1;
	thsymsets_symbols[SYMP_LOWEND][3] = 1;
	thsymsets_symbols[SYMP_LOWEND][7] = 1;
	thsymsets_symbols[SYMP_MOONMILK][7] = 1;
	thsymsets_symbols[SYMP_NARROWEND][7] = 1;
	thsymsets_symbols[SYMP_NOEQUIPMENT][5] = 1;
	thsymsets_symbols[SYMP_PALEOMATERIAL][7] = 1;
	thsymsets_symbols[SYMP_PEBBLES][1] = 1;
	thsymsets_symbols[SYMP_PEBBLES][7] = 1;
	thsymsets_symbols[SYMP_PILLAR][1] = 1;
	thsymsets_symbols[SYMP_PILLAR][7] = 1;
	thsymsets_symbols[SYMP_PILLARS][7] = 1;
	thsymsets_symbols[SYMP_POPCORN][7] = 1;
	thsymsets_symbols[SYMP_RAFT][3] = 1;
	thsymsets_symbols[SYMP_RAFTCONE][3] = 1;
	thsymsets_symbols[SYMP_RIMSTONEDAM][0] = 1;
	thsymsets_symbols[SYMP_RIMSTONEPOOL][0] = 1;
	thsymsets_symbols[SYMP_ROOT][0] = 1;
	thsymsets_symbols[SYMP_ROPE][5] = 1;
	thsymsets_symbols[SYMP_ROPELADDER][5] = 1;
	thsymsets_symbols[SYMP_SAND][1] = 1;
	thsymsets_symbols[SYMP_SAND][7] = 1;
	thsymsets_symbols[SYMP_SCALLOP][7] = 1;
	thsymsets_symbols[SYMP_SINK][1] = 1;
	thsymsets_symbols[SYMP_SINK][5] = 1;
	thsymsets_symbols[SYMP_SNOW][5] = 1;
	thsymsets_symbols[SYMP_SODASTRAW][7] = 1;
	thsymsets_symbols[SYMP_SPRING][1] = 1;
	thsymsets_symbols[SYMP_SPRING][5] = 1;
	thsymsets_symbols[SYMP_STALACTITE][1] = 1;
	thsymsets_symbols[SYMP_STALACTITE][7] = 1;
	thsymsets_symbols[SYMP_STALACTITES][7] = 1;
	thsymsets_symbols[SYMP_STALAGMITE][1] = 1;
	thsymsets_symbols[SYMP_STALAGMITE][7] = 1;
	thsymsets_symbols[SYMP_STALAGMITES][7] = 1;
	thsymsets_symbols[SYMP_STATION][5] = 1;
	thsymsets_symbols[SYMP_STATION_FIXED][0] = 1;
	thsymsets_symbols[SYMP_STATION_FIXED][1] = 1;
	thsymsets_symbols[SYMP_STATION_NATURAL][0] = 1;
	thsymsets_symbols[SYMP_STATION_PAINTED][1] = 1;
	thsymsets_symbols[SYMP_STATION_PAINTED][5] = 1;
	thsymsets_symbols[SYMP_STATION_TEMPORARY][0] = 1;
	thsymsets_symbols[SYMP_STATION_TEMPORARY][1] = 1;
	thsymsets_symbols[SYMP_STATION_TEMPORARY][5] = 1;
	thsymsets_symbols[SYMP_STEPS][5] = 1;
	thsymsets_symbols[SYMP_TRAVERSE][5] = 1;
	thsymsets_symbols[SYMP_VEGETABLEDEBRIS][0] = 1;
	thsymsets_symbols[SYMP_VIAFERRATA][5] = 1;
	thsymsets_symbols[SYMP_WALLCALCITE][7] = 1;
	thsymsets_symbols[SYMP_WATER][1] = 1;
	thsymsets_symbols[SYMP_WATER][7] = 1;
	thsymsets_symbols[SYMP_WATERFLOW_INTERMITTENT][7] = 1;
	thsymsets_symbols[SYMP_WATERFLOW_PALEO][7] = 1;
	thsymsets_symbols[SYMP_WATERFLOW_PERMANENT][7] = 1;
	thsymsets_symbols[SYML_ARROW][5] = 1;
	thsymsets_symbols[SYML_BORDER_PRESUMED][5] = 1;
	thsymsets_symbols[SYML_BORDER_TEMPORARY][5] = 1;
	thsymsets_symbols[SYML_BORDER_VISIBLE][5] = 1;
	thsymsets_symbols[SYML_CEILINGMEANDER][4] = 1;
	thsymsets_symbols[SYML_CEILINGMEANDER][5] = 1;
	thsymsets_symbols[SYML_CEILINGMEANDER][7] = 1;
	thsymsets_symbols[SYML_CEILINGSTEP][4] = 1;
	thsymsets_symbols[SYML_CEILINGSTEP][5] = 1;
	thsymsets_symbols[SYML_CEILINGSTEP][7] = 1;
	thsymsets_symbols[SYML_CHIMNEY][4] = 1;
	thsymsets_symbols[SYML_CHIMNEY][7] = 1;
	thsymsets_symbols[SYML_CONTOUR][1] = 1;
	thsymsets_symbols[SYML_CONTOUR][5] = 1;
	thsymsets_symbols[SYML_CONTOUR][7] = 1;
	thsymsets_symbols[SYML_FIXEDLADDER][5] = 1;
	thsymsets_symbols[SYML_FLOORMEANDER][5] = 1;
	thsymsets_symbols[SYML_FLOORSTEP][1] = 1;
	thsymsets_symbols[SYML_FLOORSTEP][7] = 1;
	thsymsets_symbols[SYML_FLOWSTONE][1] = 1;
	thsymsets_symbols[SYML_FLOWSTONE][7] = 1;
	thsymsets_symbols[SYML_GRADIENT][2] = 1;
	thsymsets_symbols[SYML_GRADIENT][7] = 1;
	thsymsets_symbols[SYML_HANDRAIL][5] = 1;
	thsymsets_symbols[SYML_MAPCONNECTION][5] = 1;
	thsymsets_symbols[SYML_MOONMILK][7] = 1;
	thsymsets_symbols[SYML_OVERHANG][1] = 1;
	thsymsets_symbols[SYML_OVERHANG][5] = 1;
	thsymsets_symbols[SYML_PIT][1] = 1;
	thsymsets_symbols[SYML_PIT][7] = 1;
	thsymsets_symbols[SYML_ROCKBORDER][7] = 1;
	thsymsets_symbols[SYML_ROCKEDGE][7] = 1;
	thsymsets_symbols[SYML_ROPE][5] = 1;
	thsymsets_symbols[SYML_ROPELADDER][5] = 1;
	thsymsets_symbols[SYML_SECTION][5] = 1;
	thsymsets_symbols[SYML_SLOPE][2] = 1;
	thsymsets_symbols[SYML_SLOPE][5] = 1;
	thsymsets_symbols[SYML_STEPS][5] = 1;
	thsymsets_symbols[SYML_SURVEY_CAVE][1] = 1;
	thsymsets_symbols[SYML_SURVEY_CAVE][5] = 1;
	thsymsets_symbols[SYML_SURVEY_CAVE][7] = 1;
	thsymsets_symbols[SYML_SURVEY_SURFACE][5] = 1;
	thsymsets_symbols[SYML_VIAFERRATA][5] = 1;
	thsymsets_symbols[SYML_WALL_BEDROCK][7] = 1;
	thsymsets_symbols[SYML_WALL_BLOCKS][1] = 1;
	thsymsets_symbols[SYML_WALL_BLOCKS][5] = 1;
	thsymsets_symbols[SYML_WALL_CLAY][1] = 1;
	thsymsets_symbols[SYML_WALL_CLAY][5] = 1;
	thsymsets_symbols[SYML_WALL_DEBRIS][1] = 1;
	thsymsets_symbols[SYML_WALL_DEBRIS][5] = 1;
	thsymsets_symbols[SYML_WALL_FLOWSTONE][1] = 1;
	thsymsets_symbols[SYML_WALL_ICE][1] = 1;
	thsymsets_symbols[SYML_WALL_ICE][5] = 1;
	thsymsets_symbols[SYML_WALL_MOONMILK][1] = 1;
	thsymsets_symbols[SYML_WALL_OVERLYING][1] = 1;
	thsymsets_symbols[SYML_WALL_PEBBLES][1] = 1;
	thsymsets_symbols[SYML_WALL_PEBBLES][5] = 1;
	thsymsets_symbols[SYML_WALL_PIT][1] = 1;
	thsymsets_symbols[SYML_WALL_PRESUMED][4] = 1;
	thsymsets_symbols[SYML_WALL_PRESUMED][7] = 1;
	thsymsets_symbols[SYML_WALL_SAND][1] = 1;
	thsymsets_symbols[SYML_WALL_SAND][5] = 1;
	thsymsets_symbols[SYML_WALL_UNDERLYING][1] = 1;
	thsymsets_symbols[SYML_WALL_UNDERLYING][7] = 1;
	thsymsets_symbols[SYML_WALL_UNSURVEYED][5] = 1;
	thsymsets_symbols[SYML_WATERFLOW_CONJECTURAL][5] = 1;
	thsymsets_symbols[SYML_WATERFLOW_INTERMITTENT][5] = 1;
	thsymsets_symbols[SYML_WATERFLOW_PERMANENT][7] = 1;
	thsymsets_symbols[SYMA_BEDROCK][5] = 1;
	thsymsets_symbols[SYMA_BLOCKS][1] = 1;
	thsymsets_symbols[SYMA_BLOCKS][5] = 1;
	thsymsets_symbols[SYMA_CLAY][1] = 1;
	thsymsets_symbols[SYMA_CLAY][5] = 1;
	thsymsets_symbols[SYMA_DEBRIS][1] = 1;
	thsymsets_symbols[SYMA_DEBRIS][5] = 1;
	thsymsets_symbols[SYMA_DEBRIS][7] = 1;
	thsymsets_symbols[SYMA_DIMENSIONS][5] = 1;
	thsymsets_symbols[SYMA_FLOWSTONE][0] = 1;
	thsymsets_symbols[SYMA_ICE][1] = 1;
	thsymsets_symbols[SYMA_ICE][5] = 1;
	thsymsets_symbols[SYMA_MOONMILK][5] = 1;
	thsymsets_symbols[SYMA_PEBBLES][1] = 1;
	thsymsets_symbols[SYMA_PEBBLES][5] = 1;
	thsymsets_symbols[SYMA_SAND][1] = 1;
	thsymsets_symbols[SYMA_SAND][7] = 1;
	thsymsets_symbols[SYMA_SNOW][1] = 1;
	thsymsets_symbols[SYMA_SNOW][5] = 1;
	thsymsets_symbols[SYMA_SUMP][1] = 1;
	thsymsets_symbols[SYMA_SUMP][5] = 1;
	thsymsets_symbols[SYMA_SUMP][7] = 1;
	thsymsets_symbols[SYMA_WATER][1] = 1;
	thsymsets_symbols[SYMA_WATER][5] = 1;
	thsymsets_symbols[SYMA_WATER][7] = 1;
}
